Condukt.Sandbox.Local (Condukt v0.16.5)

Copy Markdown View Source

Sandbox that operates against the host filesystem and host shell.

This is the default sandbox. It carries a base :cwd (resolved at init/1) that all relative paths and command executions use as their root.

mount/3 is unsupported (the host filesystem is the sandbox).

Initializing

{:ok, sandbox} = Condukt.Sandbox.new(Condukt.Sandbox.Local, cwd: "/tmp")