Condukt.Sandbox.Virtual.Tools.Mount (Condukt v0.16.5)

Copy Markdown View Source

Sandbox-specific tool for Condukt.Sandbox.Virtual that lets the agent mount a host directory into the virtual filesystem at runtime.

This tool only makes sense with the Virtual sandbox. Routing through the generic Condukt.Sandbox.mount/3 facade means it will return {:error, :not_supported} against Sandbox.Local, which is the correct behavior (the host filesystem is already the sandbox there, mounting would be meaningless).

Parameters

  • host_path - Absolute path on the host filesystem
  • vfs_path - Absolute path inside the virtual filesystem to mount it at

Summary

Functions

Callback implementation for Condukt.Tool.description/1.

Callback implementation for Condukt.Tool.name/1.

Callback implementation for Condukt.Tool.parameters/1.

Functions

description(list)

Callback implementation for Condukt.Tool.description/1.

name(list)

Callback implementation for Condukt.Tool.name/1.

parameters(list)

Callback implementation for Condukt.Tool.parameters/1.