Condukt.Secrets.Providers.Env (Condukt v0.16.5)

Copy Markdown View Source

Loads a session secret from the host process environment.

secrets: [
  GH_TOKEN: {:env, "GH_TOKEN"}
]

Trusted callers can pass :fetch_env with a System.fetch_env/1-compatible function when they need an alternate environment source.