Tool for making surgical edits to files.
Finds exact text in a file and replaces it with new text. The old_text must match exactly, including whitespace.
All filesystem access goes through the active Condukt.Sandbox.
Parameters
path- Path to the file to editold_text- Exact text to find and replace (must match exactly)new_text- New text to replace the old text with
Notes
- The match is exact and case-sensitive
- Whitespace and indentation must match exactly
- The target text must appear exactly once
- For multiple replacements, provide more context to make each match unique
Summary
Functions
Callback implementation for Condukt.Tool.description/1.
Callback implementation for Condukt.Tool.name/1.
Callback implementation for Condukt.Tool.parameters/1.
Functions
Callback implementation for Condukt.Tool.description/1.
Callback implementation for Condukt.Tool.name/1.
Callback implementation for Condukt.Tool.parameters/1.